OC.L10N.register(
    "core",
    {
    "Please select a file." : "請選取一個檔案。",
    "File is too big" : "檔案太大",
    "The selected file is not an image." : "選取的檔案不是圖片檔。",
    "The selected file cannot be read." : "選取的檔案無法讀取。",
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 中 upload_max_filesize 條目設定的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 條目指定的限制",
    "The file was only partially uploaded" : "檔案僅部份上傳",
    "No file was uploaded" : "沒有檔案上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "無法將檔案寫入磁碟",
    "A PHP extension stopped the file upload" : "有個 PHP 擴充功能停止檔案的上傳",
    "Invalid file provided" : "提供的檔案無效",
    "No image or file provided" : "未提供圖片或檔案",
    "Unknown filetype" : "未知的檔案類型",
    "An error occurred. Please contact your admin." : "發生錯誤，請聯絡管理員。",
    "Invalid image" : "無效的圖片",
    "No temporary profile picture available, try again" : "沒有臨時用的個人檔案圖片，請再試一次",
    "No crop data provided" : "未設定剪裁",
    "No valid crop data provided" : "未提供有效的剪裁設定",
    "Crop is not square" : "剪裁設定不是正方形",
    "State token does not match" : "狀態代符不相符",
    "Invalid app password" : "無效的應用程式密碼",
    "Could not complete login" : "嘗試登入時發生錯誤",
    "State token missing" : "狀態代符遺失",
    "Your login token is invalid or has expired" : "您的登入代符無效或已過期",
    "Please use original client" : "請使用原始客戶端",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "這個 Nextcloud 的社群版本沒有得到支援，而且推播通知會有所限制。",
    "Login" : "登入",
    "Unsupported email length (>255)" : "不支援的電子郵件長度 (>255)",
    "Password reset is disabled" : "密碼重設已停用",
    "Could not reset password because the token is expired" : "無法重設密碼，因為代符已過期",
    "Could not reset password because the token is invalid" : "無法重設密碼，因為代符無效",
    "Password is too long. Maximum allowed length is 469 characters." : "密碼太長。最大允許長度為 469 個字元。",
    "%s password reset" : "%s 密碼重設",
    "Password reset" : "密碼重設",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "點選下方的按鈕來重設您的密碼。如果您沒有要求重設密碼，請忽略這封信件。",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "點選下方的連結來重設您的密碼。如果您沒有要求重設密碼，請忽略這封信件。",
    "Reset your password" : "重設密碼",
    "The given provider is not available" : "指定的提供者不可用",
    "Task not found" : "找不到任務",
    "Internal error" : "內部錯誤",
    "Not found" : "找不到",
    "Node is locked" : "節點已鎖定",
    "Bad request" : "錯誤的請求",
    "Requested task type does not exist" : "請求的任務類型不存在",
    "Necessary language model provider is not available" : "沒有可用的語言模型程式",
    "No text to image provider is available" : "沒有可用的文字轉影像提供者",
    "Image not found" : "找不到影像",
    "No translation provider available" : "沒有可用的翻譯提供者",
    "Could not detect language" : "無法偵測語言",
    "Unable to translate" : "無法翻譯",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "修復步驟：",
    "Repair info:" : "修復資訊：",
    "Repair warning:" : "修復警告：",
    "Repair error:" : "修復錯誤：",
    "Nextcloud Server" : "Nextcloud 伺服器",
    "Some of your link shares have been removed" : "部分分享連結己被移除",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "出於安全性問題，我們必須移除您一部分的分享連結。查看更多資訊請點選連結。",
    "The account limit of this instance is reached." : "已達此站台的帳號數量上限。",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "在支援應用程式中輸入您的訂閱金鑰以增加帳號限制。這也確實為您提供了 Nextcloud Enterprise 提供的所有額外好處，並且強烈推薦用於公司的營運。",
    "Learn more ↗" : "深入瞭解 ↗",
    "Preparing update" : "準備更新",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "透過瀏覽器更新的功能已在您的 config.php 中停用，因此請使用命令列更新程式。",
    "Turned on maintenance mode" : "啟用維護模式",
    "Turned off maintenance mode" : "停用維護模式",
    "Maintenance mode is kept active" : "伺服器正處於維護模式",
    "Updating database schema" : "正在更新資料庫綱要",
    "Updated database" : "已更新資料庫",
    "Update app \"%s\" from App Store" : "從應用程式商店更新「%s」應用程式",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "檢查 %s 是否有可更新的資料庫綱要（若資料庫較大，可能需要一段時間）",
    "Updated \"%1$s\" to %2$s" : "已從「%1$s」更新至 %2$s",
    "Set log level to debug" : "設定除錯用的記錄層級",
    "Reset log level" : "重設記錄層級",
    "Starting code integrity check" : "開始檢查程式碼完整性",
    "Finished code integrity check" : "已完成程式碼完整性檢查",
    "%s (incompatible)" : "%s（不相容）",
    "The following apps have been disabled: %s" : "以下應用程式已被停用：%s",
    "Already up to date" : "已是最新版本",
    "Windows Command Script" : "Windows 命令稿",
    "Electronic book document" : "電子書文件",
    "TrueType Font Collection" : "TrueType 字型集合",
    "Web Open Font Format" : "Web 開放字型格式",
    "GPX geographic data" : "GPX 地理資料",
    "Gzip archive" : "Gzip 封存檔",
    "Adobe Illustrator document" : "Adobe Illustrator 文件",
    "Java source code" : "Java 原始碼",
    "JavaScript source code" : "JavaScript 原始碼",
    "JSON document" : "JSON 文件",
    "Microsoft Access database" : "Microsoft Access 資料庫",
    "Microsoft OneNote document" : "Microsoft OneNote 文件",
    "Microsoft Word document" : "Microsoft Word 文件",
    "Unknown" : "未知",
    "PDF document" : "PDF 文件",
    "PostScript document" : "PostScript 文件",
    "RSS summary" : "RSS 摘要",
    "Android package" : "Android 軟體包",
    "KML geographic data" : "KML 地理資料",
    "KML geographic compressed data" : "KML 地理壓縮資料",
    "Lotus Word Pro document" : "Lotus Word Pro 文件",
    "Excel spreadsheet" : "Excel 試算表",
    "Excel add-in" : "Excel 增益集",
    "Excel 2007 binary spreadsheet" : "Excel 2007 二進位試算表",
    "Excel spreadsheet template" : "Excel 試算表範本",
    "Outlook Message" : "Outlook 訊息",
    "PowerPoint presentation" : "PowerPoint 簡報",
    "PowerPoint add-in" : "PowerPoint 增益集",
    "PowerPoint presentation template" : "PowerPoint 簡報範本",
    "Word document" : "Word 文件",
    "ODF formula" : "ODF 公式",
    "ODG drawing" : "ODG 繪圖",
    "ODG drawing (Flat XML)" : "ODG 繪圖 (Flat XML)",
    "ODG template" : "ODG 範本",
    "ODP presentation" : "ODP 簡報",
    "ODP presentation (Flat XML)" : "ODP 簡報 (Flat XML)",
    "ODP template" : "ODP 範本",
    "ODS spreadsheet" : "ODS 試算表",
    "ODS spreadsheet (Flat XML)" : "ODS 試算表 (Flat XML)",
    "ODS template" : "ODS 範本",
    "ODT document" : "ODT 文件",
    "ODT document (Flat XML)" : "ODT 文件 (Flat XML)",
    "ODT template" : "ODT 範本",
    "PowerPoint 2007 presentation" : "PowerPoint 2007 簡報",
    "PowerPoint 2007 show" : "PowerPoint 2007 自動放映",
    "PowerPoint 2007 presentation template" : "PowerPoint 2007 簡報範本",
    "Excel 2007 spreadsheet" : "Excel 2007 試算表",
    "Excel 2007 spreadsheet template" : "Excel 2007 試算表範本",
    "Word 2007 document" : "Word 2007 文件",
    "Word 2007 document template" : "Word 2007 文件範本",
    "Microsoft Visio document" : "Microsoft Visio 文件",
    "WordPerfect document" : "WordPerfect 文件",
    "7-zip archive" : "7-zip 封存檔",
    "Blender scene" : "Blender 場景",
    "Bzip2 archive" : "Bzip2 封存檔",
    "Debian package" : "Debian 軟體包",
    "FictionBook document" : "FictionBook 文件",
    "Unknown font" : "未知字型",
    "Krita document" : "Krita 文件",
    "Mobipocket e-book" : "Mobipocket 電子書",
    "Windows Installer package" : "Windows 安裝程式包",
    "Perl script" : "Perl 命令稿",
    "PHP script" : "PHP 命令稿",
    "Tar archive" : "Tar 封存檔",
    "XML document" : "XML 文件",
    "YAML document" : "YAML 文件",
    "Zip archive" : "Zip 封存檔",
    "Zstandard archive" : "Zstandard 封存檔",
    "AAC audio" : "AAC 音訊",
    "FLAC audio" : "FLAC 音訊",
    "MPEG-4 audio" : "MPEG-4 音訊",
    "MP3 audio" : "MP3 音訊",
    "Ogg audio" : "Ogg 音訊",
    "RIFF/WAVe standard Audio" : "RIFF/WAVe 標準音訊",
    "WebM audio" : "WebM 音訊",
    "MP3 ShoutCast playlist" : "MP3 ShoutCast 播放清單",
    "Windows BMP image" : "Windows BMP 影像",
    "Better Portable Graphics image" : "BPG 影像",
    "EMF image" : "EMF 影像",
    "GIF image" : "GIF 影像",
    "HEIC image" : "HEIC 影像",
    "HEIF image" : "HEIF 影像",
    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 影像",
    "JPEG image" : "JPEG 影像",
    "PNG image" : "PNG 圖檔",
    "SVG image" : "SVG 影像",
    "Truevision Targa image" : "Truevision Targa 影像",
    "TIFF image" : "TIFF 影像",
    "WebP image" : "WebP 影像",
    "Digital raw image" : "數位原始影像",
    "Windows Icon" : "Windows 圖示",
    "Email message" : "電子郵件訊息",
    "VCS/ICS calendar" : "VCS/ICS 行事曆",
    "CSS stylesheet" : "CSS 樣式表",
    "CSV document" : "CSV 文件",
    "HTML document" : "HTML 文件",
    "Markdown document" : "Markdown 文件",
    "Org-mode file" : "Org-mode 檔案",
    "Plain text document" : "純文字文件",
    "Rich Text document" : "RTF 文件",
    "Electronic business card" : "電子名片",
    "C++ source code" : "C++ 原始碼",
    "LDIF address book" : "LDIF 通訊錄",
    "NFO document" : "NFO 文件",
    "PHP source" : "PHP 原始碼",
    "Python script" : "Python 命令稿",
    "ReStructuredText document" : "ReStructuredText 文件",
    "3GPP multimedia file" : "3GPP 多媒體檔案",
    "MPEG video" : "MPEG 視訊",
    "DV video" : "DV 視訊",
    "MPEG-2 transport stream" : "MPEG2 傳輸串流",
    "MPEG-4 video" : "MPEG-4 視訊",
    "Ogg video" : "Ogg 視訊",
    "QuickTime video" : "QuickTime 視訊",
    "WebM video" : "WebM 視訊",
    "Flash video" : "Flash 視訊",
    "Matroska video" : "Matroska 視訊",
    "Windows Media video" : "Windows 媒體視訊",
    "AVI video" : "AVI 視訊",
    "unknown text" : "未知的文字",
    "Hello world!" : "哈囉，世界！",
    "sunny" : "晴朗",
    "Hello {name}, the weather is {weather}" : "哈囉 {name}，今天天氣{weather}",
    "Hello {name}" : "哈囉 {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>以下是您的搜尋結果<script>警告(1)</script></strong>",
    "new" : "新",
    "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，離開本頁面在某些情況下可能會導致更新中斷。",
    "Update to {version}" : "更新到 {version}",
    "An error occurred." : "發生錯誤。",
    "Please reload the page." : "請重新載入頁面。",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗。<a href=\"{url}\">參閱論壇上的文章</a>了解問題的更多資訊。",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新失敗。請前往 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>回報此問題。",
    "Continue to {productName}" : "繼續使用 {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功。將在 %n 秒後重新導向至 {productName}。"],
    "Applications menu" : "應用程式選單",
    "Apps" : "應用程式",
    "More apps" : "更多應用程式",
    "_{count} notification_::_{count} notifications_" : ["{count} 個通知"],
    "No" : "否",
    "Yes" : "是",
    "The remote URL must include the user." : "遠端 URL 必須包含使用者。",
    "Invalid remote URL." : "無效的遠端 URL。",
    "Failed to add the public link to your Nextcloud" : "無法將公開連結新增到您的 Nextcloud",
    "Federated user" : "聯盟使用者",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "建立分享",
    "Direct link copied" : "已複製直接連結",
    "Please copy the link manually:" : "請手動複製連結：",
    "Custom date range" : "自訂日期範圍",
    "Pick start date" : "挑選開始日期",
    "Pick end date" : "挑選結束日期",
    "Search in date range" : "在日期範圍內搜尋",
    "Search in current app" : "在目前的應用程式中搜尋",
    "Clear search" : "清除搜尋",
    "Search everywhere" : "到處搜尋",
    "Searching …" : "正在搜尋…",
    "Start typing to search" : "開始輸入以搜尋",
    "No matching results" : "無相符結果",
    "Today" : "今天",
    "Last 7 days" : "過去 7 天",
    "Last 30 days" : "過去 30 天",
    "This year" : "今年",
    "Last year" : "去年",
    "Unified search" : "統一搜尋",
    "Search apps, files, tags, messages" : "搜尋應用程式、檔案、標籤、訊息",
    "Places" : "地點",
    "Date" : "日期",
    "Search people" : "搜尋人物",
    "People" : "人物",
    "Filter in current view" : "目前檢視中的篩選條件",
    "Search connected services" : "搜尋已連結的服務",
    "Results" : "結果",
    "Load more results" : "載入更多結果",
    "Search in" : "搜尋條件",
    "Log in" : "登入",
    "Logging in …" : "正在登入…",
    "Log in to {productName}" : "登入 {productName}",
    "Wrong login or password." : "錯誤的帳號或密碼。",
    "This account is disabled" : "此帳號已停用",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效。因此下一次登入將會被延時 30 秒。",
    "Account name or email" : "帳號名稱或電子郵件",
    "Account name" : "帳號名稱",
    "Server side authentication failed!" : "伺服器端認證失敗！",
    "Please contact your administrator." : "請聯絡系統管理員。",
    "Session error" : "工作階段錯誤",
    "It appears your session token has expired, please refresh the page and try again." : "您的工作階段權杖似乎已過期，請重新整理頁面並重試。",
    "An internal error occurred." : "發生內部錯誤。",
    "Please try again or contact your administrator." : "請重試，或聯絡您的系統管理員。",
    "Password" : "密碼",
    "Log in with a device" : "使用裝置登入",
    "Login or email" : "帳號或電子郵件",
    "Your account is not setup for passwordless login." : "您的帳號尚未設定無密碼登入。",
    "Your connection is not secure" : "您的連線不安全",
    "Passwordless authentication is only available over a secure connection." : "無密碼身份認證僅可用於經加密的安全連線。",
    "Browser not supported" : "瀏覽器不支援",
    "Passwordless authentication is not supported in your browser." : "您使用的瀏覽器不支援無密碼身份認證。",
    "Reset password" : "重設密碼",
    "Back to login" : "返回登入畫面",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "若此帳號存在，密碼重設郵件即已寄送至其電子郵件地址。若您未收到，請驗證您的電子郵件地址及/或帳號，並檢查您的垃圾郵件資料夾，或向您的本機管理員求助。",
    "Couldn't send reset email. Please contact your administrator." : "無法寄出重設密碼資訊。請聯絡您的管理員。",
    "Password cannot be changed. Please contact your administrator." : "密碼無法變更。請聯絡您的管理員。",
    "New password" : "新密碼",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "由於您已啟用檔案加密，重設密碼後，您的資料將無法解密。若您不確定繼續與否，請聯絡管理員。確定要繼續嗎？",
    "I know what I'm doing" : "我知道我在做什麼",
    "Resetting password" : "重設密碼",
    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步。",
    "Keep your colleagues and friends in one place without leaking their private info." : "在同一處聯繫您的同事和朋友，而不會洩漏他們的私人資訊。",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽、聯絡人、行事曆完美整合。",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議、網路研討會等 - 在您的瀏覽器與手機應用程式之中實現。",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "使用 Collabora Online 建置的文件、試算表、簡報協作工具。",
    "Distraction free note taking app." : "無干擾的筆記應用程式。",
    "Recommended apps" : "推薦的應用程式",
    "Loading apps …" : "正在載入應用程式…",
    "Could not fetch list of apps from the App Store." : "無法從應用程式商店擷取應用程式清單。",
    "App download or installation failed" : "應用程式下載或安裝失敗",
    "Cannot install this app because it is not compatible" : "由於不相容，無法安裝此應用程式",
    "Cannot install this app" : "無法安裝應用程式",
    "Skip" : "跳過",
    "Installing apps …" : "正在安裝應用程式…",
    "Install recommended apps" : "安裝推薦的應用程式",
    "Avatar of {displayName}" : "{displayName} 的頭像",
    "Settings menu" : "設定選單",
    "Loading your contacts …" : "正在載入聯絡人…",
    "Looking for {term} …" : "正在搜尋 {term}…",
    "Search contacts" : "搜尋聯絡人",
    "Reset search" : "重設搜尋",
    "Search contacts …" : "搜尋聯絡人…",
    "Could not load your contacts" : "無法載入您的聯絡人",
    "No contacts found" : "查無聯絡人",
    "Show all contacts" : "顯示所有聯絡人",
    "Install the Contacts app" : "安裝「聯絡人」應用程式",
    "Search" : "搜尋",
    "No results for {query}" : "{query} 查詢沒有結果",
    "Press Enter to start searching" : "按 Enter 開始搜尋",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["請輸入 {minSearchLength} 個或以上字元搜尋"],
    "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
    "Search starts once you start typing and results may be reached with the arrow keys" : "您一開始輸入，搜尋就會開始，可以使用方向鍵切換搜尋結果",
    "Search for {name} only" : "僅搜尋 {name}",
    "Loading more results …" : "正在載入更多結果…",
    "Forgot password?" : "忘記密碼？",
    "Back to login form" : "返回登入表單",
    "Back" : "返回",
    "Login form is disabled." : "登入表單已停用。",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登入表單已停用。使用其他登入選項（若可用）或聯絡您的管理人員。",
    "More actions" : "更多動作",
    "User menu" : "使用者選單",
    "Your guest name: {user}" : "您的訪客名稱：{user}",
    "You are currently not identified." : "目前無法辨識您的身份。",
    "Set public name" : "設定公開名稱",
    "Change public name" : "變更公開名稱",
    "Password is too weak" : "非常弱密碼",
    "Password is weak" : "弱密碼",
    "Password is average" : "一般密碼",
    "Password is strong" : "強密碼",
    "Password is very strong" : "非常強密碼",
    "Password is extremely strong" : "極弱密碼",
    "Unknown password strength" : "未知密碼強度",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "您的資料目錄與檔案似乎可從網際網路存取，因為 <code>.htaccess</code> 檔案並未生效。",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "{linkStart}閱讀說明文件{linkEnd}來瞭解如何正確設定您的伺服器",
    "Autoconfig file detected" : "偵測到自動組態檔案",
    "The setup form below is pre-filled with the values from the config file." : "下面的設定表單已預先填入設定檔中的值。",
    "Security warning" : "安全性警告",
    "Create administration account" : "建立管理員帳號",
    "Administration account name" : "管理員帳號名稱",
    "Administration account password" : "管理員帳號密碼",
    "Storage & database" : "儲存空間和資料庫",
    "Data folder" : "資料儲存位置",
    "Database configuration" : "資料庫組態",
    "Only {firstAndOnlyDatabase} is available." : "僅 {firstAndOnlyDatabase} 可用。",
    "Install and activate additional PHP modules to choose other database types." : "安裝並啟用相關 PHP 模組來選擇其他資料庫類型。",
    "For more details check out the documentation." : "請參閱說明文件了解更多細節。",
    "Performance warning" : "效能警告",
    "You chose SQLite as database." : "您選擇了 SQLite 作為資料庫。",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或開發中站台。對於正式上線用途，我們建議改用其他資料庫後端。",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若您會使用桌面版或手機版客戶端同步檔案，則強烈不建議使用 SQLite。",
    "Database user" : "資料庫使用者",
    "Database password" : "資料庫密碼",
    "Database name" : "資料庫名稱",
    "Database tablespace" : "資料庫資料表空間",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
    "Database host" : "資料庫主機",
    "localhost" : "localhost",
    "Installing …" : "正在安裝…",
    "Install" : "安裝",
    "Need help?" : "需要協助嗎？",
    "See the documentation" : "參閱說明文件",
    "{name} version {version} and above" : "{name} 版本 {version} 以上",
    "This browser is not supported" : "不支援此瀏覽器",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
    "Continue with this unsupported browser" : "繼續使用不受支援的瀏覽器",
    "Supported versions" : "支援的版本",
    "Search {types} …" : "搜尋 {types} 中…",
    "Choose {file}" : "選擇 {file}",
    "Choose" : "選擇",
    "Copy to {target}" : "複製到 {target}",
    "Copy" : "複製",
    "Move to {target}" : "移動到 {target}",
    "Move" : "移動",
    "OK" : "確定",
    "read-only" : "唯讀",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} 個檔案衝突"],
    "One file conflict" : "1 個檔案衝突",
    "New Files" : "新檔案",
    "Already existing files" : "已存在的檔案",
    "Which files do you want to keep?" : "您要保留哪一個檔案？",
    "If you select both versions, the copied file will have a number added to its name." : "如果您同時選擇兩個版本，複製的檔案名稱後面會加上編號。",
    "Cancel" : "取消",
    "Continue" : "繼續",
    "(all selected)" : "（已全選）",
    "({count} selected)" : "（已選取 {count} 項）",
    "Error loading file exists template" : "載入已存在的範本時發生錯誤",
    "Saving …" : "正在儲存…",
    "seconds ago" : "幾秒前",
    "Connection to server lost" : "伺服器連線中斷",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時發生問題，%n 秒後重新整理"],
    "Add to a project" : "新增至專案",
    "Show details" : "顯示詳細資訊",
    "Hide details" : "隱藏詳細資訊",
    "Rename project" : "重新命名專案",
    "Failed to rename the project" : "重新命名專案失敗",
    "Failed to create a project" : "建立專案失敗",
    "Failed to add the item to the project" : "新增項目至專案時失敗",
    "Connect items to a project to make them easier to find" : "將項目連結到專案以便尋找",
    "Type to search for existing projects" : "搜尋現有專案",
    "New in" : "新加入",
    "View changelog" : "檢視版本更新紀錄",
    "No action available" : "沒有可用的動作",
    "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
    "Close \"{dialogTitle}\" dialog" : "關閉「{dialogTitle}」對話方塊",
    "Email length is at max (255)" : "電子郵件長度最長 (255)",
    "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
    "Restricted" : "受限",
    "Invisible" : "隱藏",
    "Delete" : "刪除",
    "Rename" : "重新命名",
    "Collaborative tags" : "協作標籤",
    "No tags found" : "找不到標籤",
    "Clipboard not available, please copy manually" : "無法使用剪貼簿，請手動複製",
    "Personal" : "個人",
    "Accounts" : "帳號",
    "Admin" : "管理",
    "Help" : "說明",
    "Access forbidden" : "存取被拒",
    "You are not allowed to access this page." : "您無法存取此頁面。",
    "Back to %s" : "返回 %s",
    "Page not found" : "找不到頁面",
    "The page could not be found on the server or you may not be allowed to view it." : "在伺服器上找不到該頁面，或者您可能無權檢視。",
    "Too many requests" : "太多請求",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "有太多請求來自您的網路，請稍後再試。若您認為這不該發生，請聯絡系統管理員這是錯誤。",
    "Error" : "錯誤",
    "Internal Server Error" : "內部伺服器錯誤",
    "The server was unable to complete your request." : "伺服器無法完成您的請求。",
    "If this happens again, please send the technical details below to the server administrator." : "如果此問題重複發生，請寄送技術資訊給伺服器管理員。",
    "More details can be found in the server log." : "伺服器記錄檔裡面有更多細節。",
    "For more details see the documentation ↗." : "更多詳細資訊請見文件 ↗。",
    "Technical details" : "技術細節",
    "Remote Address: %s" : "遠端位置：%s",
    "Request ID: %s" : "請求 ID：%s",
    "Type: %s" : "類型：%s",
    "Code: %s" : "代碼：%s",
    "Message: %s" : "訊息：%s",
    "File: %s" : "檔案：%s",
    "Line: %s" : "行號：%s",
    "Trace" : "追蹤",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "您似乎正在嘗試重新安裝 Nextcloud。然而，檔案 CAN_INSTALL 並不在您的 config 目錄中。請在您的 config 資料夾中建立 CAN_INSTALL 檔以繼續。",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "無法從 config 資料夾中移除 CAN_INSTALL 檔案。請手動移除此檔案。",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "此應用程式需要 JavaScript 才能正常運作。請 {linkstart} 啟用 JavaScript{linkend} 然後重新載入頁面。",
    "Skip to main content" : "跳到主內容",
    "Skip to navigation of app" : "跳到應用程式導覽",
    "Go to %s" : "前往 %s",
    "Get your own free account" : "取得免費帳號",
    "Connect to your account" : "連結您的帳號",
    "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 帳號。",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "若您並未嘗試設定新裝置或應用程式，那麼某人可能正在欺騙您讓他們存取您的資料。在這種情況下，請不要繼續，請聯絡您的系統管理員。",
    "App password" : "應用程式密碼",
    "Grant access" : "授權存取",
    "Alternative log in using app password" : "使用應用程式密碼替代登入",
    "Account access" : "帳號存取",
    "Currently logged in as %1$s (%2$s)." : "目前登入為 %1$s（%2$s）。",
    "You are about to grant %1$s access to your %2$s account." : "您將授權「%1$s」存取您的 %2$s 帳號。",
    "Account connected" : "已連結帳號",
    "Your client should now be connected!" : "客戶端現在應該已連線！",
    "You can close this window." : "您可以關閉此視窗。",
    "Previous" : "上一個",
    "This share is password-protected" : "此分享受密碼保護",
    "The password is wrong or expired. Please try again or request a new one." : "密碼錯誤或過期。請重試，或重新申請。",
    "Please type in your email address to request a temporary password" : "請輸入您的電子郵件地址以申請臨時密碼",
    "Email address" : "電子郵件地址",
    "Password sent!" : "密碼已傳送！",
    "You are not authorized to request a password for this share" : "您無權為此分享請求密碼",
    "Two-factor authentication" : "雙因子認證",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的帳號已啟用進階安全機制，請選擇一個雙因子認證方法：",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "無法載入任何一個雙因子認證方法。請聯絡管理員。",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "雙因子認證已強制要求啟用，但您的帳號目前還沒設定。請聯絡管理員。",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "雙因子認證已強制要求啟用，但您的帳號目前還沒設定。請繼續設置您的雙因子認證。",
    "Set up two-factor authentication" : "設定雙因子認證",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "雙因子認證已強制要求啟用，但您的帳號目前還沒設定。請使用您的備用碼登入，或聯絡管理員協助。",
    "Use backup code" : "使用備用碼",
    "Cancel login" : "取消登入",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "您的帳號已啟用進階安全機制。請選擇提供者：",
    "Error while validating your second factor" : "驗證您的第二因素時發生錯誤",
    "Access through untrusted domain" : "經由不可信任的網域存取",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "請聯絡您的管理員。如果您就是管理員，請參考 config.sample.php 範例編輯 config/config.php 的「trusted_domains」設定。",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "關於組態設定的更多資訊，請參閱%1$s文件%2$s。",
    "App update required" : "需要更新應用程式",
    "%1$s will be updated to version %2$s" : "%1$s 將會更新至版本 %2$s",
    "The following apps will be updated:" : "將更新以下的應用程式：",
    "These incompatible apps will be disabled:" : "將停用這些不相容的應用程式：",
    "The theme %s has been disabled." : "佈景主題 %s 已被停用。",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份資料庫、config 資料夾及 data 資料夾。",
    "Start update" : "開始更新",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "在服務規模較大的安裝上，為了避免請求逾時，您也可以在安裝目錄執行下列指令：",
    "Detailed logs" : "詳細記錄檔",
    "Update needed" : "需要更新",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "因為您有超過 50 個帳號，服務規模較大，請透過命令列介面更新。",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "若需要協助，請參閱<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">說明文件</a>。",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "我知道如果還是要透過網頁介面更新，會有風險，像是可能發生請求逾時，並導致資料遺失。萬一更新失敗，我已準備好備份，並且明白如何讓站台回復運作。",
    "Upgrade via web on my own risk" : "願意承擔透過網頁更新的風險",
    "Maintenance mode" : "維護模式",
    "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 站台目前處於維護模式，需要一段時間恢復。",
    "This page will refresh itself when the instance is available again." : "在站台恢復可用之後，本頁會自動重新整理。",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員。",
    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
    "For more details see the {linkstart}documentation ↗{linkend}." : "詳細資訊請參閱 {linkstart} 文件 ↗{linkend}。",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議、網路研討會等 - 在您的瀏覽器與手機應用程式之中實現。",
    "You have not added any info yet" : "您尚未新增任何資訊",
    "{user} has not added any info yet" : "{user} 尚未新增任何資訊",
    "Error opening the user status modal, try hard refreshing the page" : "開啟使用者狀態的模組時發生問題，嘗試重新整理頁面",
    "Edit Profile" : "編輯個人檔案",
    "The headline and about sections will show up here" : "標題與關於區段將在此顯示",
    "Very weak password" : "密碼安全性極弱",
    "Weak password" : "密碼安全性弱",
    "So-so password" : "密碼安全性普通",
    "Good password" : "密碼安全性佳",
    "Strong password" : "密碼安全性極佳",
    "Profile not found" : "找不到個人檔案",
    "The profile does not exist." : "個人檔案不存在。",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄與檔案似乎可從網際網路存取，因為 .htaccess 檔案並未生效。",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "請參閱<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明文件</a>來瞭解如何正確設定您的伺服器組態。",
    "<strong>Create an admin account</strong>" : "<strong>建立管理員帳號</strong>",
    "New admin account name" : "新管理員帳號名稱",
    "New admin password" : "新管理員密碼",
    "Show password" : "顯示密碼",
    "Toggle password visibility" : "切換密碼可見性",
    "Configure the database" : "設定資料庫組態",
    "Only %s is available." : "剩下 %s 可使用。",
    "Database account" : "資料庫帳號",
    "Direct link copied to clipboard" : "直接連結已複製到剪貼簿"
},
"nplurals=1; plural=0;");
